==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ronportal/editace/polozkaeditace.php <==
<?php
/**
 * stanislav.elbl, 27.02.2021
 */

namespace RonPortal\Editace;

use Exception;
use Ron\Controls\EditField;
use Ron\DateUtils;
use Ron\StringUtils;
use Ron\TextManager;

/**
 * Radek nebo sloupec - podle typu zobrazeni (jedna osoba / seznam lidi)
 */
class PolozkaEditace extends SloupecMesicniDochazky
{
//    define('LZE_EDITOVAT_NE', 0);
//    define('LZE_EDITOVAT_ANO', 1);
//    define('LZE_EDITOVAT_CHECK', 2);

    /** @var int    0=ne, 1=ano, 2=checkbox
     *              Jestli je sloupec editovatelny (pouze v "hromadnem" zobrazeni)
     *              V zobrazeni pro jednu osobu se urcuje pomoci hodiny/dny/kalendarnidny="0/1/2", protoze je to potreba nastavit pro kazdou z techto polozek */
    var $lzeEditovat;
    /** @var string Pravo, kterym se ridi moznost editovat tento sloupec */
    var $pravaEditace = null;

    var $skrytNuly = false; // priznak, jestli ma skryt nulove hodnoty

    var $smazatPrazdny; // 0/1
    var $smazatNulovy;  // 0=ne, 1=ano, 2=jen kdyz je nulove vse a prazdna poznamka

    // MP
    var $limitRozdeleni; // limit pro stredisko - nacte se z MzdPolSumaNaRozdeleni - -1 = bez limitu
    /** @var bool       Priznak, jestli se ma zobrazit soucet. Defaultne false pro sloupec 'SQL' a true pro vsechny ostatni  */
    var $zobrazitSoucet;
    var $soucet;
    var $povinna;       // Pro poznamku - jestli je povinna, pokud je zadana hodnota MP

    /** @var string     Defaultni zobrazovana hodnota pro poznamku */
    var $defaultValue;

    // R, RP
    // var $kodTypuRozdeleni; // 0 = hlavni rozdeleni pouzite v SQL pro vyber osob
    /** @var int    -1 - podle hlavniho, 0 - kdykoliv, 1 - na zacatku, 2 - na konci */
    var $datumRozdeleni;

    var $kodLimitMaximum;   // kod casove slozky nebo mzdove polozky s limitem
    var $maximum;           // maximalni hodnota
    var $kodLimitMinimum;   // kod casove slozky nebo mzdove polozky s limitem
    var $minimum;           // minimalni hodnota
    var $povolitPrekroceni; // jestli je mozne prekrocit limit
    var $neprekrocitelnyLimit; // uplne nejmaximalnejsi limit, ktery nelze prekrocit

    var $sqlFilter; // pro typ ROZD - sql filtr pro vyber rozdeleni (napr. Hlavni = 1 )

    // nastaveni pro zobrazeni a editaci ve zpracovane dochazce
    var $zobrazitHodiny;  // 0 = nezobrazovat,  1 = zobrazit,  2 = editovat
    var $zobrazitDny;
    var $zobrazitKalendarniDny;

    var $zobrazitPocetJednotek;
    var $zobrazitCenuZaJednotku;
    var $zobrazitCastku;

    var $target; // pro link na editaci dochazky

    // pole pro mesicni vysledky - pro editaci ve zpracovane dochazce
    /** @var EditField */
    var $editHodiny;
    /** @var EditField */
    var $editDny;
    /** @var EditField */
    var $editKalendarniDny;

    // pole pro mzdove polozky
    /** @var EditField */
    var $editPocetJednotek;
    /** @var EditField */
    var $editCenaZaJednotku;
    /** @var EditField */
    var $editCastka;

    function __construct()
    {
        $this->limitRozdeleni = -1; // nacte se dodatecne
        $this->povolitPrekroceni = false;

        $this->soucet = 0;
        $this ->target = 'zpracovanadochazkawin';
    }


    function nactiNastaveniZRetezce($nastavenisloupce)
    {
        // popis formatu - viz nahore
        $poma = explode(':', $nastavenisloupce, 5);

        switch ($poma[0]) {
            case 'MP' : // MP:<kod>:0/1:Nadpis sloupce  -> mzdova polozka
                $this->typ = 'MP';
                $this->kod = $poma[1];
                $this->lzeEditovat = $poma[2] == '1';
                $this->nadpis = $poma[3];
                break;

            case 'MV' : // MV:<kod>:H/D/K:0/1:Nadpis sloupce  -> mesicni vysledek
                $this->typ = 'MV';
                $this->kod = $poma[1];
                $this->jednotka = $poma[2]; // H/D/K
                $this->lzeEditovat = $poma[3] == '1';
                $this->nadpis = $poma[4];
                break;

            case 'R' : // R:Nadpis sloupce  -> kod rozdeleni
                $this->typ = 'R';
                $this->nadpis = $poma[1];
                $this->lzeEditovat = false;
                break;

            case 'RP' : // R:Nadpis sloupce  -> kod rozdeleni
                $this->typ = 'RP';
                $this->nadpis = $poma[1];
                $this->lzeEditovat = false;
                break;

            default : // puvodni format <kod>:Nadpis - editovatelna mzdova polozka
                $this->lzeEditovat = 1;
                $this->kod = $poma[0];
                $this->nadpis = $poma[1];
                break;
        }
    }


//    /**
//     * @param string $kod_limit
//     * @param float $limit
//     * @param bool $povolitPrekroceniLimitu
//     * @param float $neprekrocitelnyLimit
//     */
//    function nastavLimit($kod_limit, $limit, $povolitPrekroceniLimitu, $neprekrocitelnyLimit)
//    {
//        $this->kodLimitMaximum = $kod_limit;
//        $this->maximum = $limit;
//        $this->povolitPrekroceni = $povolitPrekroceniLimitu;
//        $this->neprekrocitelnyLimit = $neprekrocitelnyLimit ?: null;
//    }


    /**
     * Nacte nastaveni sloupce ze zadaneho asociativniho pole
     * @param array $settingsArray
     * @return bool
     */
    public function loadSettings($settingsArray)
    {
        $this->lzeEditovat = 0;

        $this ->datumRozdeleni = -1;

        parent::loadSettings($settingsArray);

        $this ->zobrazitSoucet = $this ->typ !== 'SQL';

        foreach ($settingsArray as $paramName => $paramValue) {
            switch ($paramName) {
                case 'kod_limit' :
                    $this ->kodLimitMaximum = $paramValue;
                    break;

                case 'limit' :
                case 'maximum' :
                    $this ->maximum = $paramValue;
                    break;

                case 'neprekrocitelnylimit' :
                    $this->neprekrocitelnyLimit = $paramValue;
                    break;

                case 'kod_limit_minimum' :
                    $this ->kodLimitMinimum = $paramValue;
                    break;

                case 'lzeeditovat' :
                    $this ->lzeEditovat = ($paramValue === 'check')
                        ? 2 // checkbox
                        : (int)$paramValue;
                    break;

                case 'pravaeditace' :
                    $this ->pravaEditace = $paramValue;
                    break;

                case 'smazatprazdny' :
                    $this ->smazatPrazdny = (int)$paramValue;
                    break;

                case 'smazatnulovy' :
                    $this ->smazatNulovy = (int)$paramValue;
                    break;

                case 'povolitprekrocenilimitu' :
                    $this ->povolitPrekroceni = (int)$paramValue;
                    break;

                case 'typrozdeleni' :
                    $this ->kodTypuRozdeleni = (int)$paramValue;
                    break;

                case 'datumrozdeleni' :
                    $this ->datumRozdeleni = (int)$paramValue;
                    break;

                case 'default' :
                    $this ->defaultValue = $paramValue; // iconv('utf-8', 'windows-1250', $paramValue);
                    break;

                // nastaveni pro zobrazeni ve zpracovane dochazce
                case 'hodiny' : // 0 = nezobrazovat,  1 = zobrazit,  2 = editovat
                    $this->zobrazitHodiny = (int)$paramValue;
                    break;

                case 'dny' : // 0 = nezobrazovat,  1 = zobrazit,  2 = editovat
                    $this->zobrazitDny = (int)$paramValue;
                    break;

                case 'kalendarnidny' : // 0 = nezobrazovat,  1 = zobrazit,  2 = editovat
                    $this->zobrazitKalendarniDny = (int)$paramValue;
                    break;

                case 'pocetjednotek' :
                    $this->zobrazitPocetJednotek = (int)$paramValue;
                    break;

                case 'cenazajednotku' :
                    $this->zobrazitCenuZaJednotku = (int)$paramValue;
                    break;

                case 'castka' :
                    $this->zobrazitCastku = (int)$paramValue;
                    break;

                case 'sqlfiltr' :
                    $this ->sqlFilter = $paramValue;
                    break;

                case 'skrytnuly' :
                    $this ->skrytNuly = (int)$paramValue;
                    break;

                case 'zobrazitsoucet' :
                    $this ->zobrazitSoucet = (int)$paramValue;
                    break;

                case 'skrytNuly' :
                case 'lzeEditovat' :
                case 'smazatPrazdny' :
                case 'smazatNulovy' :
                case 'povinna' :
                case 'zobrazitSoucet' :
                    $this ->{$paramName} = (int)$paramValue;
                    break;

                case 'sql' :
                case 'sqlFilter' :
                case 'minimum' :
                case 'target' :
                case 'neprekrocitelnyLimit' :
                case 'kodLimitMaximum' :
                case 'kodLimitMinimum' :
                case 'pravaEditace' :
                    $this ->{$paramName} = $paramValue;
                    break;
            }
        }

        switch ($this->typ) {
            case 'ROZD' :
            case 'ROZDP' :
            case 'ROZDIMG' :
                if (!isset($this ->kodTypuRozdeleni)) {
                    $this->kodTypuRozdeleni = 0;
                }
                if (!$this ->styl) {
                    $this->styl = 'text-align:left';
                }
                break;

            case 'RP' :
            case 'R' :
                $this->kodTypuRozdeleni = 0; // typ rozdeleni nelze nastavit
                if (!$this ->styl) {
                    $this->styl = 'text-align:left';
                }
                break;

            case 'JMENO' :
            case 'JMENOPRIJMENI' :
                if (!isset($this ->nadpis)) {
                    $this ->nadpis = TextManager::_('Jmeno');
                }
                break;

            case 'OSOBNICISLO' :
                if (!isset($this ->nadpis)) {
                    $this ->nadpis = TextManager::_('Osobni_cislo');
                }
                break;
        }


        if ($this ->rozlisitRozdeleni === 3) {
            $this ->lzeEditovat = 0; // pokud se nastavuje rozdeleni podle rozdeleni osoby, tak neni povolena editace
        }

        return true;
    }


    /**
     * Vraci true, pokud je hodnota ve formatu hh:mm, jinak false
     * @return bool
     */
    public function isTimeFormat()
    {
        if ($this->typ === 'MP') {
            return false;
        }

        if ($this->jednotka === 'H') {
            return true;
        }

        return false;
    }


    public function isNumberFormat()
    {
        if ($this->typ === 'MP') {
            return true;
        }

        if ($this->typ === 'MV' && $this->jednotka !== 'H') {
            return true;
        }

        return false;
    }


    public function vratTextProHodnotu($hodnota)
    {
        if (!isset($hodnota)) {
            return ''; // hodnota vubec neni nastavena
        }

        if (!$hodnota && $this->skrytNuly) {
            return ''; // nulova hodnota se nema zobrazovat => prazdny text
        }

        if ($this->isTimeFormat()) {
            return StringUtils::format('hodiny', $hodnota);
        }

        if ($this->isNumberFormat()) {
            return StringUtils::format($this->format ?: 'number2', $hodnota);
        }

        return $hodnota;
    }



    /**
     * Prevede text zadany uzivatelem na hodnotu
     * @throws Exception
     */
    public function vratHodnotuProText($text)
    {
        if ($text == '') {
            return 0;
        }

        if ($this->isTimeFormat()) {
            return DateUtils::timeStringToFloat($text);
        }

        return StringUtils::stringToFloat($text);
    }


    public function HTMLStyl() {
        if ($this ->styl) {
            return $this ->styl;
        }

        if ($this ->typ === 'MP' || $this ->typ === 'MV') {
            return 'text-align:right';
        }

        return '';
    }

}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2311_175.zip: ronportal/ronportal/editace/polozkaeditace.php <==
<?php
/**
 * stanislav.elbl, 27.02.2021
 */

namespace RonPortal\Editace;

use Exception;
use Ron\Controls\EditField;
use Ron\DateUtils;
use Ron\StringUtils;
use Ron\TextManager;

/**
 * Radek nebo sloupec - podle typu zobrazeni (jedna osoba / seznam lidi)
 */
class PolozkaEditace extends SloupecMesicniDochazky
{
//    define('LZE_EDITOVAT_NE', 0);
//    define('LZE_EDITOVAT_ANO', 1);
//    define('LZE_EDITOVAT_CHECK', 2);

    /** @var int    0=ne, 1=ano, 2=checkbox
     *              Jestli je sloupec editovatelny (pouze v "hromadnem" zobrazeni)
     *              V zobrazeni pro jednu osobu se urcuje pomoci hodiny/dny/kalendarnidny="0/1/2", protoze je to potreba nastavit pro kazdou z techto polozek */
    public $lzeEditovat;
    /** @var string Pravo, kterym se ridi moznost editovat tento sloupec */
    public $pravaEditace = null;

    public $skrytNuly = false; // priznak, jestli ma skryt nulove hodnoty

    public $smazatPrazdny; // 0/1
    public $smazatNulovy;  // 0=ne, 1=ano, 2=jen kdyz je nulove vse a prazdna poznamka

    // MP
    public $limitRozdeleni; // limit pro stredisko - nacte se z MzdPolSumaNaRozdeleni - -1 = bez limitu
    /** @var bool       Priznak, jestli se ma zobrazit soucet. Defaultne false pro sloupec 'SQL' a true pro vsechny ostatni  */
    public $zobrazitSoucet;
    public $soucet;
    public $povinna;       // Pro poznamku - jestli je povinna, pokud je zadana hodnota MP

    /** @var string     Defaultni zobrazovana hodnota pro poznamku */
    public $defaultValue;

    /** @var null|string[]      Povolene moznosti pro editaci */
    public $options = null;

    // R, RP
    // public $kodTypuRozdeleni; // 0 = hlavni rozdeleni pouzite v SQL pro vyber osob
    /** @var int    -1 - podle hlavniho, 0 - kdykoliv, 1 - na zacatku, 2 - na konci */
    public $datumRozdeleni;

    public $kodLimitMaximum;   // kod casove slozky nebo mzdove polozky s limitem
    public $maximum;           // maximalni hodnota
    public $kodLimitMinimum;   // kod casove slozky nebo mzdove polozky s limitem
    public $minimum;           // minimalni hodnota
    public $povolitPrekroceni; // jestli je mozne prekrocit limit
    public $neprekrocitelnyLimit; // uplne nejmaximalnejsi limit, ktery nelze prekrocit

    public $sqlFilter; // pro typ ROZD - sql filtr pro vyber rozdeleni (napr. Hlavni = 1 )

    // nastaveni pro zobrazeni a editaci ve zpracovane dochazce
    public $zobrazitHodiny;  // 0 = nezobrazovat,  1 = zobrazit,  2 = editovat
    public $zobrazitDny;
    public $zobrazitKalendarniDny;

    public $zobrazitPocetJednotek;
    public $zobrazitCenuZaJednotku;
    public $zobrazitCastku;

    public $target; // pro link na editaci dochazky

    // pole pro mesicni vysledky - pro editaci ve zpracovane dochazce
    /** @var EditField */
    public $editHodiny;
    /** @var EditField */
    public $editDny;
    /** @var EditField */
    public $editKalendarniDny;

    // pole pro mzdove polozky
    /** @var EditField */
    public $editPocetJednotek;
    /** @var EditField */
    public $editCenaZaJednotku;
    /** @var EditField */
    public $editCastka;

    function __construct()
    {
        $this->limitRozdeleni = -1; // nacte se dodatecne
        $this->povolitPrekroceni = false;

        $this->soucet = 0;
        $this ->target = 'zpracovanadochazkawin';
    }


    function nactiNastaveniZRetezce($nastavenisloupce)
    {
        // popis formatu - viz nahore
        $poma = explode(':', $nastavenisloupce, 5);

        switch ($poma[0]) {
            case 'MP' : // MP:<kod>:0/1:Nadpis sloupce  -> mzdova polozka
                $this->typ = 'MP';
                $this->kod = $poma[1];
                $this->lzeEditovat = $poma[2] == '1';
                $this->nadpis = $poma[3];
                break;

            case 'MV' : // MV:<kod>:H/D/K:0/1:Nadpis sloupce  -> mesicni vysledek
                $this->typ = 'MV';
                $this->kod = $poma[1];
                $this->jednotka = $poma[2]; // H/D/K
                $this->lzeEditovat = $poma[3] == '1';
                $this->nadpis = $poma[4];
                break;

            case 'R' : // R:Nadpis sloupce  -> kod rozdeleni
                $this->typ = 'R';
                $this->nadpis = $poma[1];
                $this->lzeEditovat = false;
                break;

            case 'RP' : // R:Nadpis sloupce  -> kod rozdeleni
                $this->typ = 'RP';
                $this->nadpis = $poma[1];
                $this->lzeEditovat = false;
                break;

            default : // puvodni format <kod>:Nadpis - editovatelna mzdova polozka
                $this->lzeEditovat = 1;
                $this->kod = $poma[0];
                $this->nadpis = $poma[1];
                break;
        }
    }


//    /**
//     * @param string $kod_limit
//     * @param float $limit
//     * @param bool $povolitPrekroceniLimitu
//     * @param float $neprekrocitelnyLimit
//     */
//    function nastavLimit($kod_limit, $limit, $povolitPrekroceniLimitu, $neprekrocitelnyLimit)
//    {
//        $this->kodLimitMaximum = $kod_limit;
//        $this->maximum = $limit;
//        $this->povolitPrekroceni = $povolitPrekroceniLimitu;
//        $this->neprekrocitelnyLimit = $neprekrocitelnyLimit ?: null;
//    }


    /**
     * Nacte nastaveni sloupce ze zadaneho asociativniho pole
     * @param array $settingsArray
     * @return bool
     */
    public function loadSettings($settingsArray)
    {
        $this->lzeEditovat = 0;

        $this ->datumRozdeleni = -1;

        parent::loadSettings($settingsArray);

        $this ->zobrazitSoucet = $this ->typ !== 'SQL';

        foreach ($settingsArray as $paramName => $paramValue) {
            switch ($paramName) {
                case 'kod_limit' :
                    $this ->kodLimitMaximum = $paramValue;
                    break;

                case 'limit' :
                case 'maximum' :
                    $this ->maximum = $paramValue;
                    break;

                case 'neprekrocitelnylimit' :
                    $this->neprekrocitelnyLimit = $paramValue;
                    break;

                case 'kod_limit_minimum' :
                    $this ->kodLimitMinimum = $paramValue;
                    break;

                case 'lzeeditovat' :
                    $this ->lzeEditovat = ($paramValue === 'check')
                        ? 2 // checkbox
                        : (int)$paramValue;
                    break;

                case 'pravaeditace' :
                    $this ->pravaEditace = $paramValue;
                    break;

                case 'smazatprazdny' :
                    $this ->smazatPrazdny = (int)$paramValue;
                    break;

                case 'smazatnulovy' :
                    $this ->smazatNulovy = (int)$paramValue;
                    break;

                case 'povolitprekrocenilimitu' :
                    $this ->povolitPrekroceni = (int)$paramValue;
                    break;

                case 'typrozdeleni' :
                    $this ->kodTypuRozdeleni = (int)$paramValue;
                    break;

                case 'datumrozdeleni' :
                    $this ->datumRozdeleni = (int)$paramValue;
                    break;

                case 'default' :
                    $this ->defaultValue = $paramValue; // iconv('utf-8', 'windows-1250', $paramValue);
                    break;

                // nastaveni pro zobrazeni ve zpracovane dochazce
                case 'hodiny' : // 0 = nezobrazovat,  1 = zobrazit,  2 = editovat
                    $this->zobrazitHodiny = (int)$paramValue;
                    break;

                case 'dny' : // 0 = nezobrazovat,  1 = zobrazit,  2 = editovat
                    $this->zobrazitDny = (int)$paramValue;
                    break;

                case 'kalendarnidny' : // 0 = nezobrazovat,  1 = zobrazit,  2 = editovat
                    $this->zobrazitKalendarniDny = (int)$paramValue;
                    break;

                case 'pocetjednotek' :
                    $this->zobrazitPocetJednotek = (int)$paramValue;
                    break;

                case 'cenazajednotku' :
                    $this->zobrazitCenuZaJednotku = (int)$paramValue;
                    break;

                case 'castka' :
                    $this->zobrazitCastku = (int)$paramValue;
                    break;

                case 'sqlfiltr' :
                    $this ->sqlFilter = $paramValue;
                    break;

                case 'skrytnuly' :
                    $this ->skrytNuly = (int)$paramValue;
                    break;

                case 'zobrazitsoucet' :
                    $this ->zobrazitSoucet = (int)$paramValue;
                    break;

                case 'options' :
                    $this ->options = explode(';', $paramValue);
                    break;

                case 'skrytNuly' :
                case 'lzeEditovat' :
                case 'smazatPrazdny' :
                case 'smazatNulovy' :
                case 'povinna' :
                case 'zobrazitSoucet' :
                    $this ->{$paramName} = (int)$paramValue;
                    break;

                case 'sql' :
                case 'sqlFilter' :
                case 'minimum' :
                case 'target' :
                case 'neprekrocitelnyLimit' :
                case 'kodLimitMaximum' :
                case 'kodLimitMinimum' :
                case 'pravaEditace' :
                    $this ->{$paramName} = $paramValue;
                    break;
            }
        }

        switch ($this->typ) {
            case 'ROZD' :
            case 'ROZDP' :
            case 'ROZDIMG' :
                if (!isset($this ->kodTypuRozdeleni)) {
                    $this->kodTypuRozdeleni = 0;
                }
                if (!$this ->styl) {
                    $this->styl = 'text-align:left';
                }
                break;

            case 'RP' :
            case 'R' :
                $this->kodTypuRozdeleni = 0; // typ rozdeleni nelze nastavit
                if (!$this ->styl) {
                    $this->styl = 'text-align:left';
                }
                break;

            case 'JMENO' :
            case 'JMENOPRIJMENI' :
                if (!isset($this ->nadpis)) {
                    $this ->nadpis = TextManager::_('Jmeno');
                }
                break;

            case 'OSOBNICISLO' :
                if (!isset($this ->nadpis)) {
                    $this ->nadpis = TextManager::_('Osobni_cislo');
                }
                break;
        }


        if ($this ->rozlisitRozdeleni === 3) {
            $this ->lzeEditovat = 0; // pokud se nastavuje rozdeleni podle rozdeleni osoby, tak neni povolena editace
        }

        return true;
    }


    /**
     * Vraci true, pokud je hodnota ve formatu hh:mm, jinak false
     * @return bool
     */
    public function isTimeFormat()
    {
        if ($this->typ === 'MP') {
            return false;
        }

        if ($this->jednotka === 'H') {
            return true;
        }

        return false;
    }


    public function isNumberFormat()
    {
        if ($this->typ === 'MP') {
            return true;
        }

        if ($this->typ === 'MV' && $this->jednotka !== 'H') {
            return true;
        }

        return false;
    }


    public function vratTextProHodnotu($hodnota)
    {
        if (!isset($hodnota)) {
            return ''; // hodnota vubec neni nastavena
        }

        if (!$hodnota && $this->skrytNuly) {
            return ''; // nulova hodnota se nema zobrazovat => prazdny text
        }

        if ($this->isTimeFormat()) {
            return StringUtils::format('hodiny', $hodnota);
        }

        if ($this->isNumberFormat()) {
            return StringUtils::format($this->format ?: 'number2', $hodnota);
        }

        return $hodnota;
    }



    /**
     * Prevede text zadany uzivatelem na hodnotu
     * @throws Exception
     */
    public function vratHodnotuProText($text)
    {
        if ($text == '') {
            return 0;
        }

        if ($this->isTimeFormat()) {
            return DateUtils::timeStringToFloat($text);
        }

        return StringUtils::stringToFloat($text);
    }


    public function HTMLStyl() {
        if ($this ->styl) {
            return $this ->styl;
        }

        if ($this ->typ === 'MP' || $this ->typ === 'MV') {
            return 'text-align:right';
        }

        return '';
    }

}
